/*************************************************************************
 *	creator 	: @niuyaozong
 *	Function	: 国债逆回购页面数据解析,客户端返回数据均在此文件解析
 *	Date		：2017-12-12
 *************************************************************************/


/*******************************************************************
 * creator		: @niuyaozong
 * function		: 解析从自运营服务器查询的行情数据
 * Date			: 2017-12-12
 * parameter	: strParam : json字符串 格式:'{"local" : *, "reply" : *}' 
 * 				  local.reqStart : 请求开始时间戳
 * 				  reply.ret_code : 请求返回码 
 * 				  reply.ret_msg  : 请求返回信息 
 * 				  reply.data     : 请求返回国债行情数据 zqdm（证券代码），zxjg（最新价），mrjg1~mrjg5（买一~买五）
 * return		: 匿名json对象 obj : 日志数据
 * 				  jsonParam['retcode']   : 返回码 0成功，其他失败
 * 				  jsonParam['retmsg']    : 返回信息
 * 				  jsonParam['reqStart']  : 请求开始时间戳
 * 				  jsonParam['strParam']  : 请求原始返回数据
 * 				  array : 国债行情数据，二维数组，[i][0]（证券代码），[i][1]（最新价），[i][2]~[i][6]（买一~买五）
 * *****************************************************************/
function GZNHG_ParseHqDataFromZyy(strParam) 
{
	var strToObj = new Function("return " + strParam)();
	var jsonParam = {};
	var parse_array = new Array();
	
	jsonParam['retcode'] = '0';
	jsonParam['retmsg'] = '请求成功';
	jsonParam['strParam'] = window.JSON.stringify(strToObj);
	var ObjBody = strToObj.zxjg;
	for(var i = 0; i < ObjBody.length; i++ )
	{
		parse_array[i] = new Array();

		parse_array[i][0] =  ObjBody[i]['zqdm'];
		parse_array[i][1] =  ObjBody[i]['zxjg'];
	}
	return {
			'obj' : jsonParam, 
			'array': parse_array
			};
}

/*******************************************************************
 * creator		: @chenshuaineng
 * function		: 解析行情客户端推送行情数据(B2B端)
 * Date			: 2019-11-01
 * parameter	: strParam  : json字符串 格式:'{"xxxxxx_zxjg" : "xx.xx", "xxxxxx_zxjg" : "xx.xx", ...}'其中xxxxxx为证券代码
 * return       : parse_array  : json对象，证券代码
 * 				  jsonParam['zqdm']    : 证券代码
 * 				  jsonParam['zxjg']    : 最新价
 * *****************************************************************/
function GZNHG_ParseHqDataFromHqNewPrice(strParam)
{
	var jsonParam = {};
	var parse_array = new Array();
	
	jsonParam['retcode'] = '0';
	jsonParam['retmsg'] = '请求成功';
	
	var jsonData = window.JSON.parse(strParam);
	var arrStockCode = "204001,204002,204003,204004,204007,204014,204028,204091,204182,131810,131811,131800,131809,131801,131802,131803,131805,131806";
	arrStockCode = arrStockCode.split(",");
	var i = 0;
	for(var nIndex in arrStockCode)
	{
		var zqdm = arrStockCode[nIndex];
		parse_array[i] = new Array();
		parse_array[i][0] =  zqdm;
		zqdm = zqdm + "_zxjg"
		if (jsonData[zqdm] == undefined)
		{
			parse_array[i][1] = "-1";
		}
		else
		{
			parse_array[i][1] = jsonData[zqdm];
		}
		i++;
	}
	return {
			'obj' : jsonParam, 
			'array': parse_array
			};
}
/*******************************************************************
 * creator		: @niuyaozong
 * function		: 解析行情客户端推送行情数据
 * Date			: 2017-12-12
 * parameter	: strParam  : json字符串 格式:'{"zqdm" : *, "zxjg" : *, ...}' 
 * 				  zqdm      : 证券代码
 * 				  zxjg      : 最新价 
 * 				  mrj1~mrj5 : 买一价~买五价 
 * return       : jsonData  : json对象，证券代码，买一价~买五价
 * 				  jsonParam['zqdm']    : 证券代码
 * 				  jsonParam['zxjg']    : 最新价
 * 				  jsonParam['mrj1']~jsonParam['mrj5']  : 买一价~买五价
 * *****************************************************************/
function GZNHG_ParseHqDataFromHq(strParam)
{
	var jsonParam = window.JSON.parse(strParam);
	var jsonData = {};
	jsonData["zqdm"] = jsonParam["zqdm"];
	jsonData["zxjg"] = jsonParam["zxjg"];
	jsonData["mrj1"] = jsonParam["mrj1"];
	jsonData["mrj2"] = jsonParam["mrj2"];
	jsonData["mrj3"] = jsonParam["mrj3"];
	jsonData["mrj4"] = jsonParam["mrj4"];
	jsonData["mrj5"] = jsonParam["mrj5"];
	
	return jsonData;
}
/*******************************************************************
 * creator		: @牛耀宗
 * function		: 解析委托返回数据
 * Date			: 2017-12-12
 * parameter	: strParam : json字符串 格式:'{"local" : *, "reply" : *}' 
 * 				  local.reqStart : 请求开始时间戳
 * 				  local.htbh     : 合同编号
 * 				  local.gdzh     : 股东账号
 * 				  local.kyzj     : 可用资金
 * 				  local.wtData   : 委托数据（证券名称_证券代码_市场代码_委托价格_委托数量_委托金额）
 * 				  reply.ret_code : 请求返回状态码 
 * 				  reply.ret_msg  : 请求返回信息 
 * return		: jsonParam : json对象; 
 * 				  jsonParam['retcode']   : 返回码 0成功，其他失败
 * 				  jsonParam['retmsg']    : 返回信息
 * 				  jsonParam['reqStart']  : 请求开始时间戳
 * 				  jsonParam['strParam']  : 请求原始返回数据
 * 				  jsonParam['htbh']      : 合同编号
 * 				  jsonParam['gdzh']      : 股东账号
 * 				  jsonParam['wtData']    : 委托数据（证券名称_证券代码_市场代码_委托价格_委托数量_委托金额）
 * *****************************************************************/
function GZNHG_ParseWtData(strParam)
{
	var strToObj = new Function("return " + strParam)();
	
	var retcode = strToObj.reply.ret_code;
	var retmsg = strToObj.reply.ret_msg;
	var jsonParam = {};
	
	jsonParam['retcode'] = retcode;
	jsonParam['retmsg'] = retmsg;
	// jsonParam['reqStart'] = strToObj.local.reqStart;
	// jsonParam['gdzh'] = strToObj.local.gdzh;		//股东账号
	// jsonParam['wtData'] = strToObj.local.wtData;	//委托数据
	jsonParam['strParam'] = window.JSON.stringify(strToObj);	//回调入参
	
	if(retcode == "0" && retmsg == '')	//retcode 表示委托成功
	{
		jsonParam['retmsg'] = '委托成功';
	}
	else if(retmsg == '')
	{
		jsonParam['retmsg'] = '委托数据异常';
	}
	
	jsonParam['htbh'] = strToObj.reply.htbh || '';	//合同编号
	
	return  jsonParam;
}
/*******************************************************************
 * creator		: @niuyaozong
 * function		: 解析从自运营服务器查回的国债信息
 * Date			: 2017-12-12
 * parameter	: strParam : json字符串 格式:'{"reply" : *}' 
 * 				  reply.table.table     : 请求返回国债行情数据 xd_2102（股票代码），xd_2103（股票名称），xd_2167（市场代码），xd_2001（资金占用天数，这里通过接口查回来）
 * return		: 匿名json对象 obj : 日志数据; 
 * 				  jsonParam['retcode']   : 返回码 0成功，其他失败
 * 				  jsonParam['retmsg']    : 返回信息
 * 				  jsonParam['reqStart']  : 请求开始时间戳
 * 				  jsonParam['strParam']  : 请求原始返回数据
 * 				  array : 国债信息数据，二维数组，[i][0]（股票代码），[i][1]（股票名称），[i][2]（显示名称），[i][3]（市场代码）[i][4]（手续费天数），[i][5]（资金占用天数）
 * *****************************************************************/
function GZNHG_ParseGzInfoFromZyy(strParam)
{
	//测试数据用的！由于返回数据量较多，弹框无法显示全，写入文件看！
	// var fso = new ActiveXObject("Scripting.FileSystemObject"); 
	// var f=fso.createtextfile("d:\\a.txt",2,true);
	// f.writeLine(strParam);
	// f.close();
	//测试数据end
	var strToObj = new Function("return " + strParam)();
	var retcode = strToObj.reply.ret_code;//错误号
	var retmsg = strToObj.reply.ret_msg;//错误信息
	var jsonParam = {};
	var parse_array = new Array();
	if (retcode != 0) 
	{
		jsonParam['retcode'] = retcode;
		jsonParam['retmsg'] = retmsg;
		return {
			'obj' : jsonParam, 
			'array': parse_array
			};
	}
	var qsid_num = strToObj.reply.qsid_num;
	if (qsid_num != undefined)
	{//券商id，部分特殊券商有不同表现，需要设置的
		g_qsid = qsid_num;
	}
	if (strToObj.reply.table == undefined)
	{
		jsonParam['retcode'] = -999;
		jsonParam['retmsg'] = "获取国债数据异常";
		return {
			'obj' : jsonParam, 
			'array': parse_array
			};
	}
	var strZKTS = strToObj.reply.table.table;
	
	jsonParam['retcode'] = 0;
	jsonParam['retmsg'] = '获取国债信息成功';
	jsonParam['reqStart'] = '1535090025386';
	jsonParam['strParam'] = '';
	
	var ret_str = '[{\"SETNAME\":\"1天期\",\"sxfDays\":\"1\",\"SETCODE\":\"2\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"GC001\",\"STOCKCODE\":\"204001\"},{\"SETNAME\":\"2天期\",\"sxfDays\":\"2\",\"SETCODE\":\"2\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"GC002\",\"STOCKCODE\":\"204002\"},{\"SETNAME\":\"3天期\",\"sxfDays\":\"3\",\"SETCODE\":\"2\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"GC003\",\"STOCKCODE\":\"204003\"},{\"SETNAME\":\"4天期\",\"sxfDays\":\"4\",\"SETCODE\":\"2\",\"zjzyDays\":\"2\",\"STOCKNAME\":\"GC004\",\"STOCKCODE\":\"204004\"},{\"SETNAME\":\"7天期\",\"sxfDays\":\"5\",\"SETCODE\":\"2\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"GC007\",\"STOCKCODE\":\"204007\"},{\"SETNAME\":\"14天期\",\"sxfDays\":\"10\",\"SETCODE\":\"2\",\"zjzyDays\":\"14\",\"STOCKNAME\":\"GC014\",\"STOCKCODE\":\"204014\"},{\"SETNAME\":\"28天期\",\"sxfDays\":\"20\",\"SETCODE\":\"2\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"GC028\",\"STOCKCODE\":\"204028\"},{\"SETNAME\":\"91天期\",\"sxfDays\":\"30\",\"SETCODE\":\"2\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"GC091\",\"STOCKCODE\":\"204091\"},{\"SETNAME\":\"182天期\",\"sxfDays\":\"30\",\"SETCODE\":\"2\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"GC182\",\"STOCKCODE\":\"204182\"},{\"SETNAME\":\"1天期\",\"sxfDays\":\"1\",\"SETCODE\":\"1\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"R-001\",\"STOCKCODE\":\"131810\"},{\"SETNAME\":\"2天期\",\"sxfDays\":\"2\",\"SETCODE\":\"1\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"R-002\",\"STOCKCODE\":\"131811\"},{\"SETNAME\":\"3天期\",\"sxfDays\":\"3\",\"SETCODE\":\"1\",\"zjzyDays\":\"1\",\"STOCKNAME\":\"R-003\",\"STOCKCODE\":\"131800\"},{\"SETNAME\":\"4天期\",\"sxfDays\":\"4\",\"SETCODE\":\"1\",\"zjzyDays\":\"2\",\"STOCKNAME\":\"R-004\",\"STOCKCODE\":\"131809\"},{\"SETNAME\":\"7天期\",\"sxfDays\":\"5\",\"SETCODE\":\"1\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"R-007\",\"STOCKCODE\":\"131801\"},{\"SETNAME\":\"14天期\",\"sxfDays\":\"10\",\"SETCODE\":\"1\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"R-014\",\"STOCKCODE\":\"131802\"},{\"SETNAME\":\"28天期\",\"sxfDays\":\"20\",\"SETCODE\":\"1\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"R-028\",\"STOCKCODE\":\"131803\"},{\"SETNAME\":\"91天期\",\"sxfDays\":\"30\",\"SETCODE\":\"1\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"R-091\",\"STOCKCODE\":\"131805\"},{\"SETNAME\":\"182天期\",\"sxfDays\":\"30\",\"SETCODE\":\"1\",\"zjzyDays\":\"7\",\"STOCKNAME\":\"R-182\",\"STOCKCODE\":\"131806\"}]';
	var re = new RegExp("\\\\","g");
	ret_str = ret_str.replace(re,"");
	var ObjBody = new Function("return " + ret_str)();
		
	for(var i = 0; i < ObjBody.length; i++ )
	{
		parse_array[i] = new Array();
		//股票代码,股票名称,显示名称,市场代码,手续费天数,资金占用天数
		parse_array[i][0] = ObjBody[i]['STOCKCODE'];//证券代码
		parse_array[i][1] = ObjBody[i]['STOCKNAME'];//证券名称
		parse_array[i][2] = ObjBody[i]['SETNAME'];//证券名称
		parse_array[i][3] = ObjBody[i]['SETCODE'];//市场代码
		parse_array[i][4] = ObjBody[i]['sxfDays'];//手续费天数（写死的，通过上面表格配置！）
		if (ObjBody[i]['STOCKCODE'] == strZKTS[i]['xd_2102'])
		{
			parse_array[i][5] = strZKTS[i]['xd_2001'];
			parse_array[i][6] = strZKTS[i]['xd_2002'];
			parse_array[i][7] = strZKTS[i]['xd_2003'];
		}
		
		$('#' + g_gpxx[i]).text(ObjBody[i]['STOCKCODE'] + " " + ObjBody[i]['STOCKNAME']);
		$('#' + g_cjqx[i]).text(ObjBody[i]['SETNAME']);
	}

	return {
			'obj' : jsonParam, 
			'array': parse_array
			};
}
/*******************************************************************
 * creator		: @niuyaozong
 * function		: 解析查可用资金返回数据
 * Date			: 2017-12-12
 * parameter	: strParam : json字符串 格式:'{"local" : *, "reply" : *}' 
 * 				  local.reqStart : 请求开始时间戳
 * 				  reply.ret_code : 请求返回码 
 * 				  reply.ret_msg  : 请求返回信息 
 * 				  reply.availablemoney     : 请求返回可用资金 
 * return		: jsonParam : json对象，
 * 				  jsonParam['retcode']   : 返回码 0成功，其他失败
 * 				  jsonParam['retmsg']    : 返回信息
 * 				  jsonParam['reqStart']  : 请求开始时间戳
 * 				  jsonParam['kyzj']      : 可用资金 四舍五入保留两位有效小数
 * 				  jsonParam['strParam']  : 请求原始返回数据
 *****************************************************************/
function GZNHG_ParseZiJin(strParam)
{
	var strToObj = new Function("return " + strParam)();
	
	var retcode = strToObj.reply.ret_code;
	var retmsg = strToObj.reply.ret_msg;
	var strZijin = strToObj.reply.availablemoney || '';
	
	var jsonParam = {};
	jsonParam['retcode'] = retcode;
	jsonParam['retmsg'] = retmsg;
	// jsonParam['reqStart'] = strToObj.local.reqStart;
	jsonParam['strParam'] = window.JSON.stringify(strToObj);
	
	if(strZijin)	//''为false
	{
		jsonParam['kyzj'] = parseFloat(strZijin).toFixed(2);
		
		if(retmsg == '')
		{
			jsonParam['retmsg'] = '获取可用资金成功';
		}
	}
	else if(retmsg == '')	//数据异常
	{
		jsonParam['retmsg'] = '获取可用资金异常';
	}

	return jsonParam;
}

/*******************************************************************
 * creator		: @chenshuaineng
 * function		: 保留3位小数
 * Date			: 2018-09-17
 * parameter	: value : 原始数值 
 * return		: value : 处理后数据
 *****************************************************************/
function returnFloat(value){
	value = parseFloat(value)
	return value.toFixed(3)
}
/*******************************************************************
 * creator		: @chenshuaineng
 * function		: 解析从行情服务器查询的行情数据
 * Date			: 2017-12-12
 * parameter	: strParam : json字符串 格式:'{}' 请求返回国债行情数据 zqdm（证券代码），zxjg（最新价），mrj1~mrj5（买一~买五）
 * return		: 
 * 				  jsonParam['strParam']  : 请求原始返回数据
 * 				  array : 国债行情数据，二维数组，[i][0]（证券代码），[i][1]（最新价），[i][2]~[i][6]（买一~买五）
 * *****************************************************************/
function GZNHG_ParseHqDataFromB2B(strParam) 
{
	strParam = '['+ strParam +']'
	var strToObj = new Function("return " + strParam)();
	var jsonParam = {};
	var parse_array = new Array();
	
	jsonParam['retcode'] = '0';
	jsonParam['retmsg'] = '请求成功';
	jsonParam['strParam'] = window.JSON.stringify(strToObj);

	if(strToObj)	//校验数据
	{
		var ObjBody = strToObj;

		for(var i = 0; i < ObjBody.length; i++ )
		{
			parse_array[i] = new Array();
			parse_array[i][0] =  ObjBody[i]['zqdm'];
			parse_array[i][1] =  ObjBody[i]['zxjg'];
			parse_array[i][2] =  ObjBody[i]['mrj1'];
			parse_array[i][3] =  ObjBody[i]['mrj2'];
			parse_array[i][4] =  ObjBody[i]['mrj3'];
			parse_array[i][5] =  ObjBody[i]['mrj4'];
			parse_array[i][6] =  ObjBody[i]['mrj5'];
		}
	}
	else	//数据异常
	{
		jsonParam['retmsg'] = '从自运营获取行情数据异常';
	}

	return {
			'obj' : jsonParam, 
			'array': parse_array
			};
}